#!/usr/bin/env python
from __future__ import print_function
from setuptools import setup

setup(name="zymptest",
      version="0.1.0",
      author="Yimin Zhang",
      author_email="1018575661@qq.com",
      description="test",
      long_description=open("README.rst").read(),
      license="MIT",
      url="",
      packages=['zymptest'],
      install_requires=[],
      classifiers=[ "Environment :: Web Environment",
                    "Intended Audience :: Developers",
                    "Operating System :: Microsoft :: Windows",
                    "Topic :: Text Processing :: Indexing",
                    "Topic :: Utilities",
                    "Topic :: Internet",
                    "Topic :: Software Development :: Libraries :: Python Modules",
                    "Programming Language :: Python",
                    "Programming Language :: Python :: 2",
                    "Programming Language :: Python :: 2.6",
                    "Programming Language :: Python :: 2.7",
                    ],
      )





